========
TorchKGE
========


.. image:: https://badge.fury.io/py/torchkge.svg
    :target: https://badge.fury.io/py/torchkge

.. image:: https://travis-ci.org/torchkge-team/torchkge.svg?branch=master
    :target: https://travis-ci.org/torchkge-team/torchkge

.. image:: https://readthedocs.org/projects/torchkge/badge/?version=latest
    :target: https://torchkge.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://pyup.io/repos/github/torchkge-team/torchkge/shield.svg
     :target: https://pyup.io/repos/github/torchkge-team/torchkge/
     :alt: Updates



TorchKGE : Knowledge Graph embedding in Python and Pytorch.


* Free software: BSD license
* Documentation: https://torchkge.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
